@@ -1,4 +1,3 @@
-# -*- coding:utf-8 -*-
 """
 Description:
     Asset Type in neo
@@ -7,7 +6,7 @@ Usage:
 """
 
 
-class AssetType(object):
+class AssetType:
     CreditFlag = 0x40
     DutyFlag = 0x80
 
