@@ -1,9 +1,5 @@
-import time
 import plyvel
 import binascii
-
-from logzero import logger
-
 from neo.Core.Blockchain import Blockchain
 from neo.Core.Header import Header
 from neo.Core.Block import Block
@@ -35,6 +31,9 @@ from neocore.BigInteger import BigInteger
 from neo.EventHub import events
 
 from prompt_toolkit import prompt
+from neo.logging import log_manager
+
+logger = log_manager.getLogger('db')
 
 
 class LevelDBBlockchain(Blockchain):
@@ -209,17 +208,17 @@ class LevelDBBlockchain(Blockchain):
     def GetStates(self, prefix, classref):
         return DBCollection(self._db, prefix, classref)
 
-    def GetAccountState(self, script_hash, print_all_accounts=False):
+    def GetAccountState(self, address, print_all_accounts=False):
 
-        if type(script_hash) is str:
+        if type(address) is str:
             try:
-                script_hash = script_hash.encode('utf-8')
+                address = address.encode('utf-8')
             except Exception as e:
                 logger.info("could not convert argument to bytes :%s " % e)
                 return None
 
         accounts = DBCollection(self._db, DBPrefix.ST_Account, AccountState)
-        acct = accounts.TryGet(keyval=script_hash)
+        acct = accounts.TryGet(keyval=address)
 
         return acct
 
@@ -446,13 +445,18 @@ class LevelDBBlockchain(Blockchain):
         except Exception as e:
             pass
 
-        if not type(height_or_hash) == BigInteger and len(height_or_hash) == 64:
+        if intval is None and len(height_or_hash) == 64:
             bhash = height_or_hash.encode('utf-8')
             if bhash in self._header_index:
                 hash = bhash
 
+        elif intval is None and len(height_or_hash) == 66:
+            bhash = height_or_hash[2:].encode('utf-8')
+            if bhash in self._header_index:
+                hash = bhash
+
         elif intval is not None and self.GetHeaderHash(intval) is not None:
-            hash = self.GetHeaderHash(int(height_or_hash))
+            hash = self.GetHeaderHash(intval)
 
         if hash is not None:
             return self.GetHeader(hash)
