@@ -1,4 +1,3 @@
-# -*- coding:utf-8 -*-
 """
 Description:
     Inventory Type
@@ -7,11 +6,15 @@ Usage:
 """
 
 
-class InventoryType(object):
+class InventoryType:
     TX = b'\x01'  # Transaction
     Block = b'\x02'  # Block
     Consensus = b'\xe0'  # Consensus information
 
+    TXInt = 1
+    BlockInt = 2
+    ConsensusInt = 224
+
     @staticmethod
     def AllInventoriesInt():
         """
@@ -20,6 +23,4 @@ class InventoryType(object):
         Returns:
             list: of int formatted inventory types.
         """
-        return [int.from_bytes(InventoryType.TX, 'little'),
-                int.from_bytes(InventoryType.Block, 'little'),
-                int.from_bytes(InventoryType.Consensus, 'little')]
+        return [1, 2, 224]
