@@ -1,7 +1,5 @@
 import binascii
 import sys
-from logzero import logger
-
 from collections import deque
 from neo.VM.ExecutionEngine import ExecutionEngine
 from neo.VM import OpCode
@@ -22,13 +20,15 @@ from neo.Core.State.AssetState import AssetState
 from neo.Core.State.AccountState import AccountState
 from neo.Core.State.ValidatorState import ValidatorState
 from neo.Core.State.StorageItem import StorageItem
-
 from neo.Core.State.ContractState import ContractPropertyState
 from neo.SmartContract import TriggerType
-
+from neo.VM.InteropService import Array
 from neocore.UInt160 import UInt160
 import datetime
 from neo.Settings import settings
+from neo.logging import log_manager
+
+logger = log_manager.getLogger('vm')
 
 
 class ApplicationEngine(ExecutionEngine):
@@ -46,6 +46,9 @@ class ApplicationEngine(ExecutionEngine):
 
     maxItemSize = 1024 * 1024
     maxArraySize = 1024
+    max_shl_shr = 65535  # ushort.maxValue
+    min_shl_shr = -65535  # -ushort.maxValue
+    MaxSizeForBigInteger = 32
 
     def GasConsumed(self):
         return Fixed8(self.gas_consumed)
@@ -117,6 +120,91 @@ class ApplicationEngine(ExecutionEngine):
 
         return True
 
+    def _checkBigInteger(self, value):
+        return len(value.ToByteArray()) <= self.MaxSizeForBigInteger
+
+    def CheckBigIntegers(self):
+        cx = self.CurrentContext
+        opcode = cx.NextInstruction
+
+        if opcode == OpCode.SHL:
+            ishift = cx.EvaluationStack.Peek(0).GetBigInteger()
+
+            if ishift > self.max_shl_shr or ishift < self.min_shl_shr:
+                return False
+
+            x = cx.EvaluationStack.Peek(1).GetBigInteger()
+
+            try:
+                if not self._checkBigInteger(x << ishift):
+                    return False
+            except ValueError:
+                # negative ishift throws a value error
+                return False
+
+        if opcode == OpCode.SHR:
+            ishift = cx.EvaluationStack.Peek(0).GetBigInteger()
+
+            if ishift > self.max_shl_shr or ishift < self.min_shl_shr:
+                return False
+
+            x = cx.EvaluationStack.Peek(1).GetBigInteger()
+
+            try:
+                if not self._checkBigInteger(x >> ishift):
+                    return False
+            except ValueError:
+                # negative ishift throws a value error
+                return False
+
+        if opcode == OpCode.INC:
+            x = cx.EvaluationStack.Peek().GetBigInteger()
+            if not self._checkBigInteger(x) or not self._checkBigInteger(x + 1):
+                return False
+
+        if opcode == OpCode.DEC:
+            x = cx.EvaluationStack.Peek().GetBigInteger()
+            if not self._checkBigInteger(x) or (x.Sign <= 0 and not self._checkBigInteger(x - 1)):
+                return False
+
+        if opcode == OpCode.ADD:
+            x2 = cx.EvaluationStack.Peek().GetBigInteger()
+            x1 = cx.EvaluationStack.Peek(1).GetBigInteger()
+
+            if not self._checkBigInteger(x2) or not self._checkBigInteger(x1) or not self._checkBigInteger(x1 + x2):
+                return False
+
+        if opcode == OpCode.SUB:
+            x2 = cx.EvaluationStack.Peek().GetBigInteger()
+            x1 = cx.EvaluationStack.Peek(1).GetBigInteger()
+
+            if not self._checkBigInteger(x2) or not self._checkBigInteger(x1) or not self._checkBigInteger(x1 - x2):
+                return False
+
+        if opcode == OpCode.MUL:
+            x2 = cx.EvaluationStack.Peek().GetBigInteger()
+            x1 = cx.EvaluationStack.Peek(1).GetBigInteger()
+
+            length_x1 = len(x1.ToByteArray())
+            if length_x1 > self.MaxSizeForBigInteger:
+                return False
+
+            length_x2 = len(x2.ToByteArray())
+            if length_x2 > self.MaxSizeForBigInteger:
+                return False
+
+            if length_x1 + length_x2 > self.MaxSizeForBigInteger:
+                return False
+
+        if opcode in [OpCode.DIV, OpCode.MOD]:
+            x2 = cx.EvaluationStack.Peek().GetBigInteger()
+            x1 = cx.EvaluationStack.Peek(1).GetBigInteger()
+
+            if not self._checkBigInteger(x2) or not self._checkBigInteger(x1):
+                return False
+
+        return True
+
     def CheckItemSize(self):
 
         cx = self.CurrentContext
@@ -308,7 +396,12 @@ class ApplicationEngine(ExecutionEngine):
                         return False
 
                     if not self.CheckInvocationStack():
-                        logger.debug("INVOCATION SIZE TO BIIG")
+                        logger.debug("INVOCATION SIZE TO BIG")
+                        self._VMState |= VMState.FAULT
+                        return False
+
+                    if not self.CheckBigIntegers():
+                        logger.debug("BigIntegers check failed")
                         self._VMState |= VMState.FAULT
                         return False
 
@@ -412,9 +505,15 @@ class ApplicationEngine(ExecutionEngine):
         elif api == "Neo.Transaction.GetReferences":
             return 200
 
+        elif api == "Neo.Transaction.GetWitnesses":
+            return 200
+
         elif api == "Neo.Transaction.GetUnspentCoins":
             return 200
 
+        elif api in ["Neo.Witness.GetInvocationScript", "Neo.Witness.GetVerificationScript"]:
+            return 100
+
         elif api == "Neo.Account.SetVotes":
             return 1000
 
