@@ -2,7 +2,6 @@ import hashlib
 import datetime
 
 from neo.VM.OpCode import *
-from logzero import logger
 from neo.VM.RandomAccessStack import RandomAccessStack
 from neo.VM.ExecutionContext import ExecutionContext
 from neo.VM import VMState
@@ -12,6 +11,9 @@ from neo.Settings import settings
 from neo.VM.VMFault import VMFault
 from neo.Prompt.vm_debugger import VMDebugger
 from logging import DEBUG as LOGGING_LEVEL_DEBUG
+from neo.logging import log_manager
+
+logger = log_manager.getLogger('vm')
 
 
 class ExecutionEngine:
@@ -235,7 +237,6 @@ class ExecutionEngine:
                 script = self._Table.GetScript(UInt160(data=script_hash).ToBytes())
 
                 if script is None:
-                    logger.error("Could not find script from script table: %s " % script_hash)
                     return self.VM_FAULT_and_report(VMFault.INVALID_CONTRACT, script_hash)
 
                 context_new = self.LoadScript(script)
@@ -1011,39 +1012,16 @@ class ExecutionEngine:
 
             if self._exit_on_error:
                 self._VMState |= VMState.FAULT
-            else:
-                logger.error(error_msg)
-                logger.exception(e)
-
-    def StepOut(self):
-        self._VMState &= ~VMState.BREAK
-        count = self._InvocationStack.Count
-
-        while self._VMState & VMState.HALT == 0 and \
-                self._VMState & VMState.FAULT == 0 and \
-                self._VMState & VMState.BREAK == 0 and \
-                self._InvocationStack.Count > count:
-            self.StepInto()
-
-    def StepOver(self):
-        if self._VMState & VMState.HALT > 0 or self._VMState & VMState.FAULT > 0:
-            return
-
-        self._VMState &= ~VMState.BREAK
-        count = self._InvocationStack.Count
-
-        while self._VMState & VMState.HALT == 0 and \
-                self._VMState & VMState.FAULT == 0 and \
-                self._VMState & VMState.BREAK == 0 and \
-                self._InvocationStack.Count > count:
-            self.StepInto()
 
     def VM_FAULT_and_report(self, id, *args):
         self._VMState |= VMState.FAULT
 
-        if settings.log_level != LOGGING_LEVEL_DEBUG:
+        if not logger.hasHandlers() or logger.handlers[0].level != LOGGING_LEVEL_DEBUG:
             return
 
+        # if settings.log_level != LOGGING_LEVEL_DEBUG:
+        #     return
+
         if id == VMFault.INVALID_JUMP:
             error_msg = "Attemping to JMP/JMPIF/JMPIFNOT to an invalid location."
 
