@@ -294,10 +294,32 @@ class JsonRpcApi:
 
         elif method == "sendtoaddress":
             if self.wallet:
-                return self.send_to_address(params)
+                contract_tx, fee = self.parse_send_to_address_params(params)
+                return self.process_transaction(contract_tx=contract_tx, fee=fee)
             else:
                 raise JsonRpcError(-400, "Access denied.")
 
+        elif method == "sendfrom":
+            if self.wallet:
+                contract_tx, address_from, fee, change_addr = self.parse_send_from_params(params)
+                return self.process_transaction(contract_tx=contract_tx, fee=fee, address_from=address_from, change_addr=change_addr)
+            else:
+                raise JsonRpcError(-400, "Access denied.")
+
+        elif method == "sendmany":
+            if self.wallet:
+                contract_tx, fee, change_addr = self.parse_send_many_params(params)
+                return self.process_transaction(contract_tx=contract_tx, fee=fee, change_addr=change_addr)
+            else:
+                raise JsonRpcError(-400, "Access denied.")
+
+        elif method == "getblockheader":
+            # this should work for either str or int
+            blockheader = Blockchain.Default().GetHeaderBy(params[0])
+            if not blockheader:
+                raise JsonRpcError(-100, "Unknown block")
+            return self.get_blockheader_output(blockheader, params)
+
         raise JsonRpcError.methodNotFound()
 
     def get_custom_error_payload(self, request_id, code, message):
@@ -420,40 +442,7 @@ class JsonRpcApi:
             })
         return result
 
-    def send_to_address(self, params):
-        asset, address, amount, fee = self.parse_send_params(params)
-        standard_contract = self.wallet.GetStandardAddress()
-        signer_contract = self.wallet.GetContract(standard_contract)
-
-        output = TransactionOutput(AssetId=asset,
-                                   Value=amount,
-                                   script_hash=address)
-        contract_tx = ContractTransaction(outputs=[output])
-        tx = self.wallet.MakeTransaction(tx=contract_tx,
-                                         change_address=None,
-                                         fee=fee)
-        if tx is None:
-            raise JsonRpcError(-300, "Insufficient funds")
-
-        data = standard_contract.Data
-        tx.Attributes = [
-            TransactionAttribute(usage=TransactionAttributeUsage.Script,
-                                 data=data)
-        ]
-
-        context = ContractParametersContext(
-            tx, isMultiSig=signer_contract.IsMultiSigContract
-        )
-        self.wallet.Sign(context)
-
-        if context.Completed:
-            tx.scripts = context.GetScripts()
-            NodeLeader.Instance().Relay(tx)
-            return tx.ToJson()
-        else:
-            return context.ToJson()
-
-    def parse_send_params(self, params):
+    def parse_send_to_address_params(self, params):
         if len(params) not in [3, 4]:
             raise JsonRpcError(-32602, "Invalid params")
 
@@ -471,8 +460,121 @@ class JsonRpcApi:
         if not amount or float(params[2]) == 0:
             raise JsonRpcError(-32602, "Invalid params")
 
+        output = TransactionOutput(AssetId=asset_id,
+                                   Value=amount,
+                                   script_hash=address_to_sh)
+        contract_tx = ContractTransaction(outputs=[output])
+
         fee = Fixed8.TryParse(params[3]) if len(params) == 4 else Fixed8.Zero()
         if fee < Fixed8.Zero():
             raise JsonRpcError(-32602, "Invalid params")
 
-        return asset_id, address_to_sh, amount, fee
+        return contract_tx, fee
+
+    def parse_send_from_params(self, params):
+        if len(params) not in [4, 5, 6]:
+            raise JsonRpcError(-32602, "Invalid params")
+        asset_id = get_asset_id(self.wallet, params[0])
+        if not type(asset_id) is UInt256:
+            raise JsonRpcError(-32602, "Invalid params")
+        address_from = params[1]
+        try:
+            address_from_sh = self.wallet.ToScriptHash(address_from)
+        except Exception:
+            raise JsonRpcError(-32602, "Invalid params")
+        address_to = params[2]
+        try:
+            address_to_sh = self.wallet.ToScriptHash(address_to)
+        except Exception:
+            raise JsonRpcError(-32602, "Invalid params")
+        amount = Fixed8.TryParse(params[3], require_positive=True)
+        if not amount or float(params[3]) == 0:
+            raise JsonRpcError(-32602, "Invalid params")
+        output = TransactionOutput(AssetId=asset_id,
+                                   Value=amount,
+                                   script_hash=address_to_sh)
+        contract_tx = ContractTransaction(outputs=[output])
+        fee = Fixed8.TryParse(params[4]) if len(params) >= 5 else Fixed8.Zero()
+        if fee < Fixed8.Zero():
+            raise JsonRpcError(-32602, "Invalid params")
+        change_addr_sh = None
+        if len(params) >= 6:
+            change_addr = params[5]
+            try:
+                change_addr_sh = self.wallet.ToScriptHash(change_addr)
+            except Exception:
+                raise JsonRpcError(-32602, "Invalid params")
+        return contract_tx, address_from_sh, fee, change_addr_sh
+
+    def parse_send_many_params(self, params):
+        if type(params[0]) is not list:
+            raise JsonRpcError(-32602, "Invalid params")
+        if len(params) not in [1, 2, 3]:
+            raise JsonRpcError(-32602, "Invalid params")
+        output = []
+        for info in params[0]:
+            asset = get_asset_id(self.wallet, info['asset'])
+            if not type(asset) is UInt256:
+                raise JsonRpcError(-32602, "Invalid params")
+            address = info["address"]
+            try:
+                address = self.wallet.ToScriptHash(address)
+            except Exception:
+                raise JsonRpcError(-32602, "Invalid params")
+            amount = Fixed8.TryParse(info["value"], require_positive=True)
+            if not amount or float(info["value"]) == 0:
+                raise JsonRpcError(-32602, "Invalid params")
+            tx_output = TransactionOutput(AssetId=asset,
+                                          Value=amount,
+                                          script_hash=address)
+            output.append(tx_output)
+        contract_tx = ContractTransaction(outputs=output)
+        fee = Fixed8.TryParse(params[1]) if len(params) >= 2 else Fixed8.Zero()
+        if fee < Fixed8.Zero():
+            raise JsonRpcError(-32602, "Invalid params")
+        change_addr_sh = None
+        if len(params) >= 3:
+            change_addr = params[2]
+            try:
+                change_addr_sh = self.wallet.ToScriptHash(change_addr)
+            except Exception:
+                raise JsonRpcError(-32602, "Invalid params")
+        return contract_tx, fee, change_addr_sh
+
+    def process_transaction(self, contract_tx, fee=None, address_from=None, change_addr=None):
+        standard_contract = self.wallet.GetStandardAddress()
+        signer_contract = self.wallet.GetContract(standard_contract)
+
+        tx = self.wallet.MakeTransaction(tx=contract_tx,
+                                         change_address=change_addr,
+                                         fee=fee,
+                                         from_addr=address_from)
+        if tx is None:
+            raise JsonRpcError(-300, "Insufficient funds")
+        data = standard_contract.Data
+        tx.Attributes = [
+            TransactionAttribute(usage=TransactionAttributeUsage.Script,
+                                 data=data)
+        ]
+        context = ContractParametersContext(
+            tx, isMultiSig=signer_contract.IsMultiSigContract
+        )
+        self.wallet.Sign(context)
+        if context.Completed:
+            tx.scripts = context.GetScripts()
+            NodeLeader.Instance().Relay(tx)
+            return tx.ToJson()
+        else:
+            return context.ToJson()
+
+    def get_blockheader_output(self, blockheader, params):
+
+        if len(params) >= 2 and params[1]:
+            jsn = blockheader.ToJson()
+            jsn['confirmations'] = Blockchain.Default().Height - blockheader.Index + 1
+            hash = Blockchain.Default().GetNextBlockHash(blockheader.Hash)
+            if hash:
+                jsn['nextblockhash'] = '0x%s' % hash.decode('utf-8')
+            return jsn
+
+        return Helper.ToArray(blockheader).decode('utf-8')
